@@ -59,6 +59,8 @@ class Statistics(object):
 
     @property
     def stddev(self):
+        if self.count == 1:
+            return 0
         squares = sum([(i - self.mean) ** 2 for i in self.times])
         return (squares / (self.count - 1)) ** 0.5
 
